@@ -25,7 +25,7 @@ COMMANDS = {
     'manager': manager,
     'registry': registry,
     'controller': controller,
-    'controller': replicator,
+    'replicator': replicator,
     'lbupdater': lbupdater
 }
 
@@ -186,7 +186,7 @@ def status(ctx):
 @click.pass_context
 def help(ctx):
     """
-    Create a commands ordered dict and pass it to tree builder
+    Show tree of commands and subcommands
     """
     commands = dict(list(COMMANDS.items()) + list(cli.commands.items()))
     click.echo('%s'
